/**
 *
 * @licstart  The following is the entire license notice for the 
 * JavaScript code in this file.
 *
 * Copyright (C) 2019  nanapiisuke
 *
 * You are allowed to modify and redistribute this software
 * for any non-commercial purposes as long as this license
 * notice is not removed. Credit and a link to our website
 * at (https://wanman.neocities.org) would be appreciated
 * but is not required. 
 *
 * For any commercial usage interest contact us at
 * nanapiisuke[AT]protonmail[DOT]com
 *
 * @licend  The above is the entire license notice
 * for the JavaScript code in this file.
 *
 */

var cur_chan = [];
var cur_index = 0;
var cur_played = [];
var idlinks_mode = 1;
var is_fullscreen = false;
var is_debug = false;
const is_offline_mode = false;

function tvStatic(on = true) {
  const TV_AUDIO = document.getElementById("tv-audio");
  const TV_VIDEO = document.getElementById("tv-video");
  const TV_STATIC = document.getElementById("tv-static");
  
  // On
  if (on) {
    TV_AUDIO.play();
    TV_VIDEO.style.visibility = "hidden";
    TV_STATIC.className = "";
  }
  // Off
  else {
    TV_AUDIO.pause();
    TV_VIDEO.style.visibility = "unset";
    TV_STATIC.className = "tv-static-off";
  }
}

function tvVolAdjust(sub = false) {
  const TV_AUDIO = document.getElementById("tv-audio");
  const TV_VIDEO = document.getElementById("tv-video");
  const TV_VOL = document.getElementById("tv-vol");
  
  // Show HUD
  clearTimeout(this.vol_fade);
  this.vol_fade = setTimeout(function() {TV_VOL.style.opacity = 0;}, 3000);
  TV_VOL.style.opacity = 0.85;
  
  // Check if ready
  if (this.ready === false) {return;}
  
  // Adjust volume
  let vol = TV_VIDEO.volume;
  let hud = 0;
  switch (true) {
    // Sub
    case vol > 0 && vol < 1 && sub:
      vol = (vol - 0.1).toPrecision(2);
      hud = -1;
      break;
    // Add
    case vol > 0 && vol < 1 && !sub:
      vol = (vol + 0.1).toPrecision(2);
      hud = 1;
      break;
    // Min (0 to 0.1)
    case vol === 0 && !sub:
      vol = (vol + 0.1).toPrecision(2);
      hud = 1;
      break;
    // Max (1 to 0.9)
    case vol === 1 && sub:
      vol = (vol - 0.1).toPrecision(2);
      hud = -1;
      break;
    default:
      break;
  }
  
  // Update HUD
  switch (true) {
    // Min (0.1 to 0)
    case hud === -1 && TV_VOL.innerText === "▋":
      TV_VOL.innerText = "_";
      break;
    // Sub & Max (1 to 0.9)
    case hud === -1:
      TV_VOL.innerText = TV_VOL.innerText.replace(/ ▋/, "");
      break;
    // Min (0 to 0.1)
    case hud === 1 && TV_VOL.innerText == "_":
      TV_VOL.innerText = "▋";
      break;
    // Add
    case hud === 1:
      TV_VOL.innerText += " ▋";
      break;
    default:
      break;
  }
  
  // Update volume
  if (TV_VIDEO.volume !== vol) {
    TV_AUDIO.volume = vol;
    TV_VIDEO.volume = vol;
    // Cooldown
    this.ready = false;
    setTimeout(function() {this.ready = true;}, 50);
  }
}

function tvVolSet(vol) {
  const TV_VOL = document.getElementById("tv-vol");
  const TV_AUDIO = document.getElementById("tv-audio");
  const TV_VIDEO = document.getElementById("tv-video");
  
  // Update HUD
  if (vol === 0) {TV_VOL.innerText = "_";}
  else {
    TV_VOL.innerText = "";
    for (let i = vol * 10; i > 0; i--) {
      TV_VOL.innerText += " ▋";
    }
  }
  
  // Update volume
  TV_AUDIO.volume = vol;
  TV_VIDEO.volume = vol;
}

function tvChanName(chan = undefined, time = 7000) {
  const TV_CHANNAME = document.getElementById("tv-channame");
  
  // Update channel name
  if (chan !== undefined) {TV_CHANNAME.innerText = chan;}
  
  // Show HUD
  clearTimeout(this.chan_fade);
  this.chan_fade = setTimeout(function() {TV_CHANNAME.style.opacity = 0;}, time);
  TV_CHANNAME.style.opacity = 0.85;
}

function tvChanAdjust(up = false) {
  if (!navigator.onLine && !is_offline_mode) {return;}
  const TV_CHANBTN = Array.from(document.getElementsByClassName("tv-chanbtn"));
  
  // Check if ready
  if (this.ready === false) {return;}
  
  // Update chan_index
  let chan_index = parseInt(document.getElementById("tv-channame").innerText[2]) - 1;
  if (isNaN(chan_index)) {chan_index = 0;}
  
  // Adjust chan_index
  switch (true) {
    // Up (8 to 1)
    case up && chan_index === 7:
      TV_CHANBTN[0].click();
      break;
    // Up
    case up:
      TV_CHANBTN[chan_index + 1].click();
      break;
    // Down (1 to 8)
    case !up && chan_index === 0:
      TV_CHANBTN[7].click();
      break;
    // Down
    case !up:
      TV_CHANBTN[chan_index - 1].click();
      break;
    default:
      break;
  }
  
  // Cooldown
  this.ready = false;
  setTimeout(function() {this.ready = true;}, 100);
}

function tvRandom(arr = []) {
  return Math.floor(Math.random() * arr.length);
}

function tvIdLink(id = undefined) {
  if (idlinks_mode === 0) {return;}
  else if (id && idlinks_mode > 1) {idlinks_mode = 1;}
  else {return "https://www.invidio.us/latest_version?id=" + id + "&itag=43";}
}

function tvNext(next_index = tvRandom(cur_chan)) {
  if (!navigator.onLine && !is_offline_mode) {return;}
  const TV_VIDEO = document.getElementById("tv-video");
  
  // Show channel name
  tvChanName();
  // Reset idlinks_mode
  tvIdLink(true);
  
  // Check cur_played & set source
  if (cur_played.length === cur_chan.length) {cur_played = [cur_played[cur_played.length - 1]];}
  while (cur_played.includes(next_index) && typeof(cur_index) === "number" && cur_chan.length !== 1) {next_index = tvRandom(cur_chan);}
  TV_VIDEO.src = idlinks_mode !== 0 &&
  cur_chan[next_index].length === 11 &&
  cur_chan[next_index].match(/[0-9a-zA-Z_-]/) !== null  ? tvIdLink(cur_chan[next_index]) : cur_chan[next_index];
  
  // If network problem, seek to last position
  if (typeof(cur_index) !== "number") {TV_VIDEO.fastSeek(cur_index[1]);}
  
  // Update cur_played & play
  cur_index = next_index;
  if (!cur_played.includes(cur_index)) {cur_played.push(cur_index);}
  TV_VIDEO.play();
}

function tvFullscreen() {
  const TV_DOC = document.getElementById("tv-doc");
  if (!is_fullscreen) {
    if (TV_DOC.requestFullscreen) {TV_DOC.requestFullscreen();}
    else if (TV_DOC.mozRequestFullScreen) {TV_DOC.mozRequestFullScreen();}
    else if (TV_DOC.webkitRequestFullscreen) {TV_DOC.webkitRequestFullscreen();}
    else if (TV_DOC.msRequestFullscreen) {TV_DOC.msRequestFullscreen();}
    is_fullscreen = true;
  }
  else {
    if (document.exitFullscreen) {document.exitFullscreen();}
    else if (document.mozCancelFullScreen) {document.mozCancelFullScreen();}
    else if (document.webkitExitFullscreen) {document.webkitExitFullscreen();}
    else if (document.msExitFullscreen) {document.msExitFullscreen();}
    is_fullscreen = false;
  }
}

function tvAlert(text = undefined, sfx = false) {
  const TV_AUDIO_ERROR = document.getElementById("tv-audio-error");
  
  // Generic error
  if (text === undefined) {text = "Faulty input - try again"; sfx = true;}
  // Play sfx
  if (sfx) {TV_AUDIO_ERROR.fastSeek(0); TV_AUDIO_ERROR.play();}
  // Alert
  alert(text);
}

function tvPrompt(text = undefined) {
  const TV_VIDEO = document.getElementById("tv-video");
  
  // Prompt
  text = prompt(text);
  // Unpause if paused
  if (TV_VIDEO.paused) {TV_VIDEO.play();}
  // If cancel
  if (text === null) {return false;}
  // If faulty input
  if (text === undefined || text === "" || text.match(/[^ ]+/) === null) {tvAlert(); return false;}
  // Return input
  else {return text;}
}

function tvDurSeek(input = undefined, seek = false) {
  const TV_VIDEO = document.getElementById("tv-video");
  
  // Duration
  if (!seek) {
    // Convert seconds to hour, min, secs
    if (input === undefined) {input = TV_VIDEO.duration;}
    let h = Math.floor(input / 3600);
    let m = Math.floor(input % 3600 / 60);
    let s = Math.floor(input % 3600 % 60);

    h = h > 0 ? h + "h" : "";
    m = m > 0 ? m + "m" : "";
    s = s >= 0 ? s + "s" : "";
    return h + m + s;
  }
  // Seek
  else {
    let seek_time = [/(\d+)h/, /(\d+)m/, /(\d+)s/, 0];
    for (let i = 0; i < 3; i++) {
      let seek_matches;
      seek_matches = input.match(seek_time[i]);
      
      // Check faulty input
      if (seek_matches === null || input.match(/[^hms\d]/)) {continue;}
      else {seek_matches = parseInt(seek_matches[1]);}
      
      // Convert to seconds
      switch (i) {
        case 0:
          seek_matches = seek_matches * 3600;
          break;
        case 1:
          seek_matches = seek_matches * 60;
          break;
        default:
          break;
      }

      // Update
      seek_time[3] += seek_matches === 0 ? 0.1 : seek_matches;
    }
    
    // Check faulty input & seek
    if (seek_time[3] === 0 || seek_time[3] > TV_VIDEO.duration) {tvAlert();}
    else {TV_VIDEO.fastSeek(seek_time[3]);}
  }
}

function tvDebug(type = 0, extra = false) {
  if (!is_debug) {return;}
  const TV_VIDEO = document.getElementById("tv-video");
  
  switch (type) {
    // Debug channel
    case 0:
      if (cur_chan !== extra) {cur_chan = extra; cur_played = []; tvChanName("DBG");}
      tvNext();
      break;
    // Debug current video info
    case 1:
      let text = extra ? "ビデオエラー" : "ビデオインフォ";
      text = text + "\n- cur_chan[cur_index] -\n" + cur_chan[cur_index] + "\n- TV_VIDEO.src -\n" + TV_VIDEO.src;
      if (idlinks_mode !== 0 && TV_VIDEO.src.includes("invidio.us/latest_version?id=")) {text += "\n- video id -\n" + TV_VIDEO.src.match(/id=([0-9a-zA-Z_-]{11})/)[1];}
      tvAlert(text, extra);
      break;
    // Debug video seek
    case 2:
      if (TV_VIDEO.readyState !== HTMLMediaElement.HAVE_ENOUGH_DATA) {break;}
      TV_VIDEO.pause();
      let seek = tvPrompt("Enter seek time\nFormat: XhYmZs (i.e. 1h5m20s, 5m, 1h20s etc)\nVideo length: " + tvDurSeek() + "\nCurrent time: " + tvDurSeek(TV_VIDEO.currentTime));
      if (!seek) {break;}
      seek = tvDurSeek(seek, true);
      break;
    // Debug aspect cover
    case 3:
      TV_VIDEO.style.objectFit = "cover";
      break;
    // Debug aspect fill
    case 4:
      TV_VIDEO.style.objectFit = "fill";
      break;
    // Debug new video src
    case 5:
      let new_src = tvPrompt("Enter new video source link\nYouTube or invidio.us links and ids are also supported", true);
      if (!new_src) {break;}
      else if (new_src.includes("watch?v=")) {new_src = tvIdLink(new_src.match(/watch\?v=(.{11})/)[1]);}
      else if (new_src.includes("youtu.be/")) {new_src = tvIdLink(new_src.match(/youtu\.be\/(.{11})/)[1]);}
      else if (new_src.length === 11 && new_src.match(/[0-9a-zA-Z_-]/) !== null) {new_src = tvIdLink(new_src);}
      tvStatic();
      tvIdLink(true);
      TV_VIDEO.src = new_src;
      break;
    default:
      break;
  }
}

function tvInit() {
  /* Channels */
  const CHANNELS = [
    // Internets
    ["pitG-tr4A9o", "yCr4O7570b0", "UqHvTYLZWHY", "wmobNjld7X8", "ODgaf9dAyac", "_Tt_7FUx7wk", "O1dgS24pvXo", "XpHuAFtyhfE", "y96azjzPgW0", "OEmWy055h2Y", "_-ZLUTOl0ZY", "Uzet-Dt-4K8", "vG-l-f8RcmQ", "sVRMSmftZZM", "0TbtWntaKts", "sswwjfbI7Y8", "sBUAUQfr8F4", "76-54EcQT_g", "4X9Nzj5Y88M", "SSBpBVGkidI", "UjjsoniUZD4", "4BMNErlqQMs", "oahEB2C3npk", "Wj76YgiwdmM", "jj8bjA5Rd-c", "vvtZiCxeOhA", "--fjCLtwkGk", "g6nnd8LDTsI", "mr8tGojYFPI", "YXpZ0uRMDR0", "Ed4tvFXS3Tw", "buRFjDSIu4o", "UNLJZPcq3Zs", "y3yyYYLyVzw", "AqyCNIllQ7o", "gThlC2JYAOk", "5DPFnZkPyRo", "H_13BVmiANU", "ivZ_l9tPrvk", "l69v6SVoE9k", "wmdICpXIECU", "8kX5_69sO8Q", "SRam9zcijao", "79N1O0lF0GY", "TIbZDRXM-Tg", "1F_wUNd2B4U", "uwwU55zBYlQ", "_4peBs-hux8", "WiUjG9fF3zw", "9bnFEb3qrT0", "KmvydnVTriE", "rmYU2ikxjpA", "zkLJoFp2UAE", "_2u8UQNPc2E", "iTzSXuwdi0E", "BOTpFDnhUkc", "71fvorxmckg", "A6yYDlP0QOM", "Wjdi7a6L_78", "1EKTw50Uf8M", "2fSIggxDmFw", "t9vBmdGlyVA", "bWZUAXEMlwA", "y10G3K2aar0", "UK7im9kq2PU", "1So1yWaKGOY", "KxRZX9eDpCs", "AM4xRM7uYhU", "qHCQtYRq5k8", "Ct7GUlS4eQg", "5-AyThi8wiY", "KSAG4pMx2TA", "AHOJo6ne9zg", "oUmTJfvO1ag", "1BoYlkkVzv8", "l1S2HApi37g", "XCAakxCALLw", "spHhUu_pqNI", "Lq1uoAa2WQg", "FtutLA63Cp8", "xRCMPdOlu1g", "j_kyna_AxmE", "Hd8DAZROJmw", "faQSs6UBDok", "0OZyleriwRU", "x57yIcRiRR4", "YD_4hIUOcvs", "Vfn5XVekJyM", "n0IEftMUgDU", "1GTCS_6dz7c", "KmjuUxzUU9w", "4xtN9rJ-RFg", "wfRZMgCmdN4", "ssbnKctoq9g", "gKqmq7QVIrM", "5N1FyQjv-Ls", "VHcBjr8aHvc", "N7jkEK33QC4", "agV4sCUmUvQ", "BxbYwIGcETg", "Fil_4OvyKec", "nBeuDEN0jAo", "ka6bGnnVXTs", "8aAV0b35odw", "UwGiyxgNEO0", "mco3UX9SqDA", "8mOneTXstmU", "-jiFrDwenq4", "VlIeCb-RwUk", "uDSVcBb6CnU", "GxtVw7_JEqE", "9vAi6gF2ZfU", "qS0bU2Xn3l0", "fxu2G9eDB9g", "PqUpoeLVcPM", "kSMoxfkv_qM", "tYzMYcUty6s", "YeM19uf75MU", "z8om1FwP9Hk", "wAnXHYZAaZE", "q2UPRyq4UU8", "ZGJ459NfMLI", "t02KQlRvF-E", "yyxPGfQ6HlY", "2w7g8v5pbHA", "oVhCCEWgT9U", "mzqjVnhnAA0", "ZQSQBrOSLec", "DCZ2_K5WdJY", "vy_xbXIJ898", "yYHQ-N4j6zQ"],
    // Internets
    
    // Random nippon
    ["s7U5CzUKt4Y", "hThSobPyV2U", "8NtsRrT-sBU", "IOlCWbct9o4", "rW6M8D41ZWU", "pon1l_UpkzI", "sz7qNCusbsM", "tl3zs7JvOXI", "TQ32KcLe1Q8", "VwB8yFAZqu8", "cqXpaD6B8Ig", "bdsznQPpNRg", "UuKgbge6e3o", "fV7Ygrj8K0g", "py9F2fAXtC8", "R2gnIcUZuwM", "JBroq3z0jVE", "hySoCSoH-g8", "nsA9d0XOguQ", "DgIuOEKxtjc", "fqL3xyBTjaY", "E98WgiMKauk", "CW8h_1eNnEg", "V45XFQfncWA", "OZATSl1nkXE", "fXjpqbeBcRI", "g_E46NrYcnA", "buRSA8EsrTY", "6fRMvxGedCo", "490BgQS_0WE", "-86FHc845fQ", "-V0WKbHV1zM", "Ud7MX9tsJnI", "LUrkmFofCQM", "wklfl5lVGj4", "8dH_9HBUS2w", "P7GUuzjcg8I", "-XyWiQ6iuXw", "kaOwjPLSXeE", "zDGnHTaqKvs", "2zmCAfg5CuI", "JgBR-YUAWRI", "XWbmvVvVNcc", "oG04Xsjyb7k", "erIxiBsR-wg", "Tn7rx0SnPuk", "bbps6TYU8pY", "WZxXeMDXVZU", "MDUyYvYlbj4", "dczBTrjd7OA", "E8xW05CG1To", "jGtZO_BxO8M", "4jwujo5y2e0", "hQzkwawRRvs", "1H5qKI6FzeY", "FkkK6ZL6jHo", "YIcwa9y9KVY", "p_a7xUTntVo", "6kcsIpqSoB4", "9cV37JIJTcY", "KolragiOqUU", "HX0gAD56678", "0XzFy6pxsoY", "GkMP11OwE2M", "cc1R5Ck65PA", "O7D-1RG-VRk", "UzPnfJrZgf8", "PvcE9D3mn0Q", "kqSMkX4j1F4", "lwXTnYGiZVI", "DA4KxifQ0Tg", "ZahVLL6NkB8", "P0xGSXScTe4", "chIy6PLFewQ", "1sq1N1sBGsA", "feZlBkoFjM4", "1azRVySY4g8", "6PVWBuZqBkM", "3LBs-9Di18k", "Q_AOfASkrTI", "PysARfe34Ik", "TrqDf4VFmGw", "0ZX4-2fZqo4", "uoNlNsjAnpo", "EULn_Uh-vhs", "qQFuxY4CjZc", "saUFplLMccU", "fIMNrUZiwEg", "krXW41BJVT0", "rZwfEEt6W3c", "hanHrpg-n_Y", "40tXDlmp3uE", "heN_hNi37Qs", "nxNl05O5xrw", "9Ou7z9Yv3yg", "tNgr0LPCXfY", "XOyS-txt3a4", "G3F8YatJXCU", "0cqYT4WC5II", "wN4cvYDt9mg", "fCwOqidHkPQ", "W9p-yBvB0no", "ruQbvIAKHds", "3slwlggVdcQ", "q5lBF4Tn95k", "EWh8z_22SP8", "HEWx_qYTzds", "uNHG0kfnMKs", "DAkzrJBmJPM", "Uo1lldedvTk", "9oNac-RHEIk", "vjLjMoA0f8Q", "mB9aZyu5gBI", "7Hlz_FhiO7o", "za08IiCjDPk", "2jx7rSx9IoQ", "qON0RqA_ObE", "mTmoGlWKj7A", "RGzwMQCe5BA", "GkpYo-YGQI4", "f6Z0qbB6FHA", "zcy6st6bDSs", "QrSKd3wMQXs", "OfiVKAoqN7M", "SRjDDH1teug", "rbbrPrBa5sA", "lC34D1Cmt9U", "8RN-xg8qpX8", "bvN3R1TmD54", "0LcPv8wm4Qw", "aVivoCaFsNs", "JYc-TTVM9QI", "agM_6weDOKU", "K86UliZ6_1E", "DusU4MQ2KYQ", "t-pml9yd0JE", "fLPfFAMlJzI", "GTzxafufp9s", "i_soEO0NC3c", "7j_GpgkAHhU", "sT-Q0a43gyY", "Sq4KnuN6Gw0", "RK4dm6q4D3g", "CzGvKLpLpxo", "kdS37y56tcw", "Pd15no0j2ok", "zCzitW8RZ90", "CG6wML-YzLQ", "f6XX5Sov9mY", "kQUFyWNv52E", "_GabHGlGm14", "ubX_aqXctRk", "A07GRS7aXbk", "Cwq-HPJ1Nfo", "6eA3coghgQA", "LLCF7vPanrY", "8qyGY9MmkUc", "7OCkNa41A6g", "5bitDlP9dDQ", "SO1NvBd72L4", "UFT22S9euEI", "OpZkfjIkdKk", "XuxzZ3zQCl0", "-7-TWpdtVTw", "o9CaP0X_tR0", "Wa81qIEBxlM", "J8nUpPz2woM", "GCrB-Cwa5Fg", "YJg02ivYzSs", "SAK_Y90tL90", "IovywlBHXZI", "euYu86eRDdg", "XauesGq81pc", "xAAfTWtm4w0", "AkuGYYo4cik", "y6UN1n75D7E", "8btq5vdFAVY", "DkoRf5gPQxQ", "N6_-dBe0C0M", "X6kfhmMOM8o", "ZcvitejWOms", "oJRAW0r0giE", "iwcuGq5x_lM", "zZd6Yug5wiA", "8kbB4fEXymM", "q5ta9lGo1lo", "DcgfJvpAdjg", "oK2SkcSggis", "t3_QWak7tCY", "VJnDldCLjYo", "ZnYvTkaf9EU", "Y1rngzy4CDU", "s69UVGkUohM", "e-FMQvLx0G8", "5gIe2dHW2KA", "wraaO0iuzVo", "QCDfSuDm5uQ", "U6sD9zm44f8", "_R4QvU3y2zE", "47_JATy4FY8", "8uIy2BOEdKk", "28nDTT0sWBQ", "RIfgazssS2w", "TGdj2MT5tC4", "emAAIVppB6E", "xqP30lbN7lk", "FffrrOm4QyA", "03jQhLY0XM8", "lBy0MZnGRsQ", "6VS_tfZniMk", "6qvFnueIBKo", "X28A-AhroQw", "YxfK_46WhJk", "ejDULPnwgh0", "oKVvtlJy1bk", "FkOh4u30IYw", "-HGSyd6Zq9Q", "sv-soOuGXA8", "Z_G-p0HSM5w", "pijlES4vnSg", "o4GUKLAa2Fo", "UYzjxN3CPR0", "v_nGWu51RvM", "xWAri3LseLk", "08rnXT7mETc", "udae5j_oH2k", "hNbxEpzHbx4", "vZQqzcindxA", "E2HhGywoLxo", "nFKEGM7NCZY", "kIIfuLR9B7s", "qpC8q8Bemnw", "LGo2YRP51dw", "-qDDIqyHshk", "kGMDrr-9FmU", "KzlUdWqS4Hg", "PSy3P6A1AMc", "_22rTlOEMxQ", "R6s0MPR3umg", "4Rqfytjm55k", "aJXUGjjOHy0", "BvLHluVYDf0", "a1bOGQzmziM", "V_HCr2rgvzg", "eMrdpoLKkLc", "zHJz8zrSw-o", "YeuAkwwzyps", "V9H5Euf8VPQ", "Czu-bGKws1k", "Je7iMC1Ruyg", "UD_PEP-TONI", "ajaYyE6ysRU", "D152wrO2wvI", "NQ9KINzWBNg", "O4pHdzLfBEM", "6Cq0nTkJ8lk", "3JgsXE3Txa4", "5yR51TgTUwY", "sGtHh_VBTsQ", "A_twpwM-epA", "DIpKEEAckaw", "IaZCmfLcTVU", "nGCrrgXSEOk", "u-UH3EwIEIs", "UrZ0by6cJZk", "vnrQcF-jmpM", "7b4m5V1TWCk", "AtRZjV4FL7k", "VT4o4r5Nl7c", "AF7_dpqTGvg", "5I4I9b5UhmQ", "dJpq-FAxDGQ", "14NmStIMAwc", "16K-M2IzTWw", "6a30x-TRh10", "7gA6dMo_NtM", "WHmkaG__lRA", "YDuSujistJA", "w_DAYCqdkb0", "VwMbRVNsxZo", "17p9vzEL2Us", "GCCn0E2LCsY", "Yy3qpbCgqQA", "BsA-xw1H6_A", "UzjhAFwXS_A", "wMRWgp9g6ek", "Mn-KhPZqnWM", "2rzsefP1J-M", "TVw42OwFp48", "xrVncCrFJkE", "sFf0M5S0DYI", "Z_1pU6tOlFE", "LWmXza5ABGI", "b3iYYUhdX90", "Cr5TpJ6u0oA", "XiE5YohuY0c", "gXK3KIDA9Cw", "S0YAZQfaX14", "4lgOZlQJ_sw", "K7kotIPsy7o", "ugjpVI6FiJU", "kRDahClqyrw", "O8rg_hbIg4s"],
    // Random nippon
    
    // Anime
    ["wexoPcjgLIE", "o96DlRbR2cQ", "nNX_eAD2X_Q", "_StZDxiUIWE", "t96gp1jRkFc", "wPYW5_NuvTo", "sgBpZfd_j1o", "asliQB4haXw", "J3CCvb5KehQ", "DYyA3bhX_dE", "b6-2P8RgT0A", "ajTAnMqhZB8", "R57Sk_mf05c", "RQi4l0gQJMw", "sxRJY-xTRo0", "1alBVNALF10", "3jXRi3ncJbs", "OiRipFiFT8s", "g3AUeEfKTGQ", "l5_3lsDVa4w", "UCrURkb8KhA", "nwDJkpe71K0", "JBHZd9eSkZI", "U7kQcHv4XNU", "MpU1d7M9hKM", "U79eYdqEwQI", "tGes1JadbOc", "ryleo8Kn4Bg", "baffzTGDrAw", "wZMoP-rcVnU", "6vRa61ST0Qg", "JRF5TIhshlo", "e17ZtYpbQPE", "bEJz3Mu9JE8", "u4JjgqVC97w", "eRSFjkXilaM", "hrO3D6fqUyY", "F55TWoMN_3M", "gSohR5kZSD4", "6vVy5t-nPqs", "Po5r9WaXk30", "szcPdUgHrR8", "DFv50ovtpgM", "PNbKIrHSLgE", "cuaCdGUamco", "sZOYHhxTPpI", "xmaN0O8kx6w", "B6jLeDeVvb4", "ZEjxssXWvlA", "qs79xcabIlc", "9CFoZg4zjOc", "37itoGOBRKY", "6FXJSrH0X8c", "g7zkB3dqyKI", "DljM2_O9U3Y", "IaP4_qyzAmY", "04N1smVhvoA", "w_rkgEoVFOA", "nbkD71LcFCU", "IMG0TmDC1OU", "0lFCoKG-wsY", "0ktD0At-8m0", "8VPscRsMZOs", "fAlWpXWMeFc", "wHjwB79-Q68", "hAtwjS4Qg3M", "iZZGpVwE9B4", "kcfsJThrnPw", "ihz1Zg94cGw", "vM2sVF_GREs", "KQkIqChNtPA", "Nma00x9q-8o", "_pBxiAtNlW0", "aNKPZqxzUc8", "sQSPFtXOKg4", "MdILg2twUx0", "3ZXK7SYMVNM", "7waowrRMBlU", "QQF5EaEl4as", "qi6hESq-eKU", "JKv0TBKfH3E", "GnJPVNkaq8w", "9e6dK4LXCKY", "IF8QOEfe-bs", "2SY4HrCTt1A", "ec6BBk3QPnA", "u6nMeGHbPFI", "aKSFf56aMtc", "eSTvYO2uiGA", "-7XOeKsv93Y", "alcbuETGjbc", "P4MgYn89Unw", "OhzebyrSEvw", "k6m9CEWPEY8", "ZfyW4X74SNU", "aAnpm9kuHnA", "aTJZDQdrBFg", "vfRsZgM-9rQ", "XJiLJ7tD-Vs", "_oPFv9YEc58", "axdJdb4HYIA", "s7ivsD9P1FA", "9oJ1pLXrTO4", "yUG6VfJczag", "h2Ur7an6eG4", "EdNbbRKtr2Y", "Oj-EVcsFR0c", "w9zsweCpjmo", "xlzdkkQPhog", "HAxQ-IBQTYo", "efkywJ00B3g", "SZ6rbw7GthU", "2uLJD1IIHkc", "J00-3JsWojI", "uPCOcz8j-ZI", "z0dGWE-23nU", "WIPmMkZshso", "5looRDC7aZc", "7wFohFg7QZw", "F0Q8qaMb0zs", "MRPdK1Z1o8c", "e2-D1UGEDgA", "xCSSYYGEIHw", "ynA09WGuedc", "x_lS3HUkXA0", "ZRPjHX8NNwI", "wXZYaCrtRok", "GHiViT90tcw", "zIVBEnJgfJw", "GHkTA0QF26Y", "qDzdbVL5Uco", "JmfqAPTYWmY", "0jX0qR9KB2E", "rGBozBZPujg", "MoPrkLSTaVw", "BVU1ismImkU", "o4uDdTRCnDk", "gHpQulGgZww", "Zh7dNaPOQv8", "xzbzSwi92fY", "wlsbl6gpaXI", "t0K44onJKMg", "oWrpEt4uIKs", "9ZKJrXPIoaI", "S7GMi5pHFzA", "5LOz1nG_o5Q", "HcbJTItAwig", "0eKg88VTHl0", "0WFNJLGgw_E", "j4S0PMfP-j0", "9JC3NK9Yikk", "j4RxsHJ5dag", "C_uPaBRjz2c", "q0NkUUqCfms", "4uR_gsZnI2I", "iWrwz8eHAE8", "_jNWXNfzcfM", "Z5Zv03qsGs8", "iWREPsuaY_g", "5qWyoOONyFM", "VhiWCob81ys", "6bw4BKPwjKw", "X2r0cmAUMYY", "QB3CBNW26X8", "vxP-F6t7XCw", "HdSstUMKg10", "PjVoYq5IlRE", "HdkqQMz0qYs", "x76AsZI8F9s", "e1qd49AwG3w", "VRQByyTT__I", "I_4i9xE_LRk", "BduTQXgKqoU", "_k3Jq_h70HE", "E5rQmGFS2dk", "lP2if5XDkNs", "Pm960RUHnCs", "wu2fKh6Epag", "VJVw1p7nQB8", "JI2etg5R9BY", "dnN-nR08PXs", "YIjnw6gM1IE", "PFlFpDcV0AA", "qOC0aXMzsOE", "l6vCdFriZbY", "2uq34TeWEdQ", "gnJ5184W3hM", "6ofOXaGv-AA", "_y1SduzXm_M", "of7mMp0Js7E", "0G3thZZHvJY", "bA2gsWE8B8U", "lO_HlBB4NEA", "YUqhCDxEJf8", "r5RQxidx4x4", "d8yVnJ1HitY", "J1ApiZTyUmg", "FIQp4PzgVG0", "0xUkykBxgsQ", "N0AAkBhkQA4", "qSDnCw-KILg", "vVxIv_SglFY", "-hsIoIp25ec", "HbGtdC6yobY", "6rFq6tNh71o", "yVF4pXHAEAI", "f3jRcthn5IQ", "XyvsZ34dB0E", "c681m7vnkp0", "zhbSOW4pAqU", "EVl7BxaDUWM", "7PpQcYX96Rw", "3lrBdkACfIo", "YbPQojDeK7E", "dp-8KIgeV68", "eJdxPOBTFMc", "3KfRnvfWOvk", "VdzrgJA_iWA", "k3o4hhaja7Q", "fnAVdjdXMOQ", "E7yDlLcQHyo", "cH1RDwGvPUA", "JTSrzflFCAU", "HtXTop4FGbQ", "z1KmgebN5cg", "iIMeo_lrv8k", "Q9ObZz87gYs", "VZJzjO1_6ZQ", "X1mGeFHqatc", "CyghWlRzRlY", "GEXZjHnDeT8", "WtDxpGYdYDA", "PBNzh27JhnU", "g7hWZMW9oeY", "Tri4FvgcKg4", "8bM_uwG2N_E", "F-XAGDR5TG4", "6iCKT-kxVMg", "cGUog81jAz4", "68GQbUbE5zc", "vJ3xkkIWrX8", "Ug53KF6TRyI", "gp3HiD8KZPc", "qMwRAS-hPzk", "W6gmfLL_TzI", "qeq1lgNRifs", "Eg2wRjo9s48", "tGd88w69Iko", "8GNDiotuRPo", "iQtHv5-0DRM", "TmsxfifhG5E", "Xjauo21VCdY", "GXE5jPCcb1s", "dPUFVbCBQcU", "M7A8q49LB7Q", "KEvB3DDJ7MA", "RtdPmQBOIgY", "oLNOeYFOdJ8", "Sze2NyaABII", "eWxiBJJ6b90", "qUCc-WHBwgU", "m1Tsv6TOCrU", "hQCWmxeLDJw", "Lc_pgcWWHQk", "dFOnTYvyb88", "1eJHZHU43NQ", "sMqJ0uR8fh4", "Im4JS5g-RPU", "9WJg7i1AtHI", "sdb8A8HEn94", "nZrpLpyWMBs", "PoZGBGOg10w", "lWH3cYBI4fo", "BnLOdZDtrPw", "3-uM1b6ujRY", "S4PWzhzpmNs", "_QD-bs1DDfo", "puMJzzBd8Dk", "h7fzWMFrci4", "skLaz_fMVi0", "6_l19pLjrHY", "udOmypSCEaI", "m8bx8mKh-WI", "eyEhyjzA1Nw", "9Jk6fI3-UU0", "FzVBNJMfg10", "GHinNpR0MNw", "cUeNK9NQPag", "vUibWNTFvwQ", "uUfz09A1aic", "owCTp0Rtk30", "HjADGQIrBrQ", "JlP1ir8apuo", "88oLsg2H98M", "IsNrN48sJww", "uWXRrSzaOCk", "TbT2DOyFQqc", "6X4SmkSOERM", "3BzpoX758ro", "hZBy0FkbixM", "f3gmXFpi9MY", "t6Oo4AxK01I", "iScfFs-YBBw", "FwETekfOhSU", "gWWFAsS-UpY", "UGOA7ubQNhE", "ZXb07L2UAi8", "54X62FFHWVk", "tH-xFvR_xiM", "ALFmT74nL5Q", "MTV60lPlfRY", "Hcw9dz9FSk0", "imuFw1QoUk4", "cWWE4OTSDB8", "OtdpRcN-EhQ", "vT77UIl_Kf8", "MhCNeizGpC8", "imHCE-0RC2k", "INcUGv8NBfI", "eKnGi3YSdPc", "C4jD6Uf28ew", "9-kmGKYsCK4", "VYuj6APzToU", "2Tv5H3Fob14", "hYPN5JfimzY", "KM1ZAgHQnmk", "rUWyNOjrh4I", "AOcF8e5Vov4", "Fzvo3M8H_cg", "VmjGHgwncSY", "DbPEE8RMjhk", "YsGj9F-70T4", "T4MwCflZWaE", "wT75ssoqstM", "qxm2BOAPlxM", "xZe5GHBFRdc", "-NANGR9nCWE", "EunYD4M2rF8", "9BFRLrOU1W8", "rdrEVLlzb1k", "H1oAczD98pk", "g4CovmXFeLM", "4GFBKYBzLZw", "_J7Go8b06nc", "02dQ2ZvCiN0", "S2jhYpDFTck", "ITL9C6_8nvE", "0eX9v1ikRJA", "LKWXHmr-y4g", "idREh6ySeG0", "3HPprl6ICak", "I5Ck0pfyG9o", "oyRztDED0Gc", "e6LWi0tfrS0", "o8LmgZEWbAE", "JlFGbBPQGLo", "anK5legaKWM", "B1jCMC0QtN4", "HPCwmK4tTK4", "JCZMQlHIBjY", "EXjFYIE8IlY", "UU5HldlD5p8", "6wGjQoJFEIc", "8AouQiB95KQ", "TEwHxMoh9Co", "EsNpI7HVa50", "y3vdt_dDipQ", "O2R7a0nrXL8", "Z9exnQDKaRA", "UEIg2LZe5JY", "M_lGixmpbGQ", "5sSI3gjZ7KA", "uhhbk3Y9GYU", "5mlTQRHyunk", "iYX8e-azGm8", "iF1Wn3X4hrI", "IROBegVGGUA", "uYR6b_dXrQU", "KQPraLKmw3Y", "1yxACNhObeA", "5ffsS3Aa8_c", "3QKriTMYnZk", "FO21QhWUj9Q", "toovspxivNs", "uYiDKTGImAQ", "RyvGDGgOBxI", "gVRHSKTX17A", "WTrWPNOW9Yc", "hfL6NlHmJrI", "m_CXe3mWWcY", "NtlVog0t84Q", "sx8JuOtkBuQ", "WVEZVys5KNU", "SYyoKrZS5Do", "QIhN9xQTwCQ", "m5gfvTOjFs8", "fq-PmphLJz8", "KTuw7cgowKs", "M8Q2YFFk69c", "yw2i8iVFMZ0", "WLuzycBBNBs", "3oY3dF75gAU", "QnB9pjAHIEg", "or0uTFypBkQ", "toUEnJg8uv8", "HHZtnr01D7Y", "yxhdluj_iSg", "esnjye2Bp88", "Gjeq04yBUz8", "4fI3PWN3ya8", "NyyQfp7teeQ", "y4Kc13JNQWI", "lDwS6L3nabY", "8ilR8F9iv4k", "jFLsOJ65N10", "TnGMJEsPf-Q", "gD7DXcaPFeM", "t1ZN7oQTnUU", "qrFEfpWlvHo", "wdsoy22AQpI", "xzb1zQB71gA", "8A5XXEnb8Uw", "Oy2YsYL981E", "YYcTOOvwYDA", "j0uYQ6-aiLk", "hrJW7olzYAA", "PLytjC0v1LU", "LfEBv1jodCA", "ihadvKl0hE0", "EUmbV9hVepk", "Aly_Fmyfg14", "Duz1Ub53-NY", "Gp2eurzKSxw", "VdrbgOqsGjw", "6dv1ZIKH3rE", "OTi11E0xgBM", "AELJMCI-v4c", "Zvo-_oHQTBg", "4QvPQpYmfew", "0vUS7dvoHS0", "iGovo81XF4U", "tGVFAyh4oxI", "fl6zrushQyU", "UMe8QGgLF_o", "dpGDT1H_UFo", "25u-qV5kMII", "Rgc--tkAUG4", "rTQm6rtxkvM", "DLUolY_pLOI", "MkhLrICefzk", "FoOKa7YBcYI", "FtM4l_nNGXQ", "6tw_vKeYQMQ", "FiIPBYJkhmg", "2DHINURW_xI", "hxPHEmz6-vM", "tPwqn_Zbm00", "ndPrQA9dEO8", "nAq-UKCwb1s", "r-qTJqAZWdo", "Q036m7tzj5c", "hKoSY9_6ln0", "5snfIBdIw2A", "r8iYzwTw1Lc", "T2lTSYtdxzw", "Hsm6gX2ZaRo", "8ld4h2xeJwg", "eYbc0cFEyzg", "B1lPohIgfpE", "XKcc9RGxG8Q", "erNn0EOjiXY", "DAxyikqRb2k", "N5Zr4MZoJlU", "2gnYSorZl5E", "tNc9I1UghaI", "JI_AZyDWmDI", "L4kSA-zXNSE", "SHOlvms_0-I", "Mfy2cK_JnmY", "Y0782TqBT-k", "49iTQ-JahhM", "YtWiOQm6PJQ", "DXhOVxsZc-k", "9395ozGPipE", "-QvMsa6Pw4M", "n3nlMGkQU9U", "2vlIUT6B40s", "MAraPQIyLzI", "zNBii4izG6U", "H4s0PI8vNJM", "oyz_pPvJ7Bw", "CpLhprOsMLc", "B5Igs_glKyQ", "vcHYPBHpkGQ", "SFlJUdZGwus", "4gz30dW4Gyk", "5ondhw3GPb4", "jgeYJ5kLwjk", "tlWFTDv4SGA", "O5Of_kik9jQ", "XZM2Av6v8bA", "H8Smv7sAoqk", "RRTwxfl-Z9o", "AKp1IKZM3v0", "p97OBKxsGn8", "rPQIbd50-9w", "ItnpVF5aCaY", "Pp5Gm2JC3HM", "8IYO9PYzIEs", "pVTPIX1aD7k", "o9_jKx0z860", "ADEecDBDpc0", "kM9OTG8eccM", "boU8FXGKoAw", "sVPbpPVkAJE", "VsQH-QAoAHM", "tjKkxjhjjOg", "YsXXhkIgLUg", "djqwUZk5SDI", "lOznlirvWrY", "3oTboWG6Ngg", "5uNxlcaAFJk", "gIQQB5kTWRs", "D26-qV6IBIw", "lO5tzzRyuqw", "MWZydtgxp98", "p8zWS4TWKUQ", "BglKvcKlJn4", "wOHB8HgkKEE", "IySZmRuvZm0", "n0-tLgwApvk", "sKswNdKOhfw", "piMqsaaHz4Q", "sjJ_JmFviGw", "IDhezU4Zl84", "H0qBX5RNupo", "4kSnz07_Oh8", "-RKgQSKpEo0", "aDgzz5bOgX0", "sISxfMm3bck", "tHrm4OiKGWY", "dnbMSjlYvD4", "ZgndrCme75o", "IBQjy6JnYyo", "W5covzq3yt0", "5U2fcARQ5vE", "YtqHzLXZqQE", "87hRzxwd3bI", "S2OwDTdMzk0", "r4mmlYqfa4k", "m77YkIqaEHE", "nVHeTt7HPmg", "kcjYOB7-Tjw", "qZdJI6jMbpY", "8Ig8BxjyUJI", "BQf5j0vxUYA", "BmR_YQdwM1Q", "RX4tgzQcyZg", "PooMQpBBa2A", "8fCmZLkZ9BA", "YspmKhfPpPc", "aYNribppV3k", "rpyc8Kk2ISk", "NOcxnFwT4Pk", "crRjpat94_c", "TpxCvZ4uCgY", "TwCbuMkjGYI", "cyAlKixVXMw", "1yN6v9UZhPM", "xoQPEPsOIEs", "7N2UcN_-wCE", "OoJin9fmsPY", "X4C0HyBkBP0", "5CTxk-4J5HY", "kHFeqI-oqV0", "kBHxP1oD9m0", "qfY6_eIr_Qo", "zuryU39UnPU", "qkBQ79kY4ao", "I4qIQXtR2bo", "GjRPAoJg5io", "Tz0c1axzsIk", "FwSRT93BZ1I", "X7qrWR3B7oQ", "W7qC_hiG-3w", "aaVB7Y8qFe4", "-CEwxOfOdSQ", "1o0fvuNT7us", "uIJZN3qDr84", "fYyip94ziuA", "YVUNy4n5fGE", "bAqpnmctPW4", "bO2ovHpyGeE", "ypPZObb45oc", "hOflruhDd2U", "pe3VELyJ6j0", "vKC3nAF4h7U", "DnbnsSfC--M", "6HV5tlYecmQ", "pkyccCvxk_g", "bR1ybgB3IR0", "IHWClTR9Zrs", "V06FxJwWO_g", "r21xCqzY8GU", "4F0OSWN8xvM", "6V-Rh7hIdwk", "lv16Y52aWRs", "TcfFR8l-qU0", "fGdIx4wFqzQ", "qOuA5231xJ8", "L0X0sn3V6l4", "oL4TNgtiwiA", "sCrA51P_Jp8", "zQ86-oQ8jrY", "mC6F75K1gt4", "IYPyXRkApC8", "yTQ0ZcWBeiw", "mtzQ7hTLzZE", "ChEBc8251rE", "mul2sCVfZkM", "tKqTfq8l8sM", "WtOf3rRgW3w", "l-REd4EDXXw", "O_iUR64ppwI", "sLPTVcpii0c", "mtbut9HkALg", "Lv6H6Rmbjwk", "vxwVPKL5aAA", "6FgoEA2Li7Y", "T7gZuCZ32Lw", "JJLXO6nXOqY", "yemeejg-LzM", "DEV2UfuKRiI", "FbVaoFVq6FA", "0WAC6j9-hxQ", "fh2nEz1k2RA", "S2aM5WPiH-E", "m4XQJ0SgIdk", "XhUT5FnpG0w", "v6h0t5UDn-8", "diuY6nERMEA", "12aOxcedqok", "legfVvbyjrI", "E-pGmi4ROdA", "1iOObgw1RTk", "h427rR7gleQ", "8A23HWxaiQg", "ieLChSKnMKo", "K83owSrTH_0", "yqDv1XXbvM", "Qf2CPkX6uEc", "LKlrjfOgE5E", "26s60KnXPok", "0WsY5C3ASuo", "UiBz4ALkEmA", "d7JDOKtyfFA", "4cLvCa8iQog", "ykyR1OTN25E", "-KuaOTC-6tE", "pAHHpYdADAQ", "b1PNJQ7GGvQ", "CcUY9LczyHg", "nNYpjHm08d8", "6w0EPz-uHM8", "PW3GujXe7pE", "07_n71I3u2Q", "0BzPgeRO73I", "nfQiQ3jRdkU", "Wy5xndgjPbg", "qdvdiKzr1wY", "rjWOWvH4k0E", "_xJVOS2Dli0", "qu0X6QKkEyk", "KVLaMyhI6MM", "cRUbt2gI-xY", "sPLHAvOOymQ", "LkPYMHm-VSU", "gO9lE9YT59w", "uW1H9mvc0X4", "NpZ5eIFjHDs", "M0DkSqTTRLQ", "l8LYV9NEgBc", "2ZSiQlekwaM", "w3tIYm689a4", "W4QNBXl6v8M", "4YP-2Dpk7s4", "Gu7Thmb6qM4", "3wcMMe-HFKI", "QwXtJg8BgqI", "WlAfP528Niw", "zs1ONiss5oM", "F3H7vEOv6Bg", "8mNn5CeUCAA", "r54xiAmkshk", "Nw5h3zIwTIg", "_6gVPzu5V-M", "Kq1FqChymvI", "xayM4wiEAKk", "OxRJY-zNusY", "mTj5WMYU2lg", "nYTIv6rFuSw", "eyRfzQe3-Cc", "yCC0SaIO--0", "TTI6nzRTluA", "pj-tdeOB_Go", "4erOmQcUseY", "Ut1fMsgMjqE", "oUWIj9B2yug", "iFuaaMUprro", "3rmikEPBonE", "ln2rPDObWdI", "7g4C8p2xjfw", "tUfPwkMwGwU", "vqcSCCQph-s", "eLsMoCncwM4", "oxyHAUQj5iU", "SKhTgOaYoOc", "mdLUg_XvXWM", "t4NIpy7sJzM", "1kkljjaLHLE", "qGSu0s773SA", "dVJhwowlAMI", "ZBmX0OldAkk", "U34Q8eainTI", "k8wi_r53aNM", "YqYq7pAmX9c", "Yj4tD9mmfEg", "i_D2ZKUQpkY", "5k10rTkcTdE", "RgvQlNCB140", "eitL7YBrMMs", "Fvi0UeMF084", "AbAnZF7BAes", "HUdSFptAgOc", "iMRziDSWDws", "YB16JEqnQiE", "-nO5Vk06m58", "ndPzn4CMEC8", "JgZgNA0tgu4", "FvLY8_jA_gs", "h2TJq_fMDFI", "S8HLl-Wluzc", "7Fu0FAFvF6c", "T4_pdLy8dc0", "F6uFy_KDeSE", "bPrvhIz-Mus", "R4etqh7gpIk", "v5znIMuEqtc", "ZVf7tS_vkvo", "f0sprdHCtd0", "gbH5vswSQz0", "0D3opggkQIk", "5NAypNIor4A", "yHtlyRj66xg", "-tF63VweOmU", "HSVbvFRnn5o", "6La9MeyWhJE", "aWDRRGaBHck", "_t_Vomhu2tw", "JITmL_2dFRU", "dEWEK55w280", "ycFS-iqjQ5I", "803p5iirXts", "Q96OQPB7axE", "xEYM612CjRM", "vkrG0Djqddw", "nIkOXV4kMZI", "UY47utPsA5A", "L44z3dUTLII", "HAIYpXplLqQ", "24tptq8afIM", "xfYkz2m6Zs4", "-5t8bucbiKE", "W_6pgez53RQ", "M0Zc5REWaJc", "YXdxjgrhh_I", "s4BQVRhmAL4", "URuqzP7MEWQ", "1m6INa72DhI", "i48gWdQEtLQ", "Lt_CaTPr3wY", "4UfhknxN_TQ", "WfYiDVFGcd0", "YgQ94TMH4nc", "LJMW9T97hfI", "P4YIWwSBp4w", "aqJEjigA7Og", "KdN2XVWc_28", "GrjJvxZbaUc", "v3u2GTKy8gI", "n8HpbRGYSfw", "OuCvH6bdkeE", "k1R-_tq818A", "N75DOjkr5og"],
    // Anime
    
    // Geemu
    ["_4FtMFFdjqc", "zeKxDEKsigQ", "oVMTQYmKfJo", "5sn0ChfKImQ", "NflsB9-ZsjI", "2PmagR8__Qs", "VExRwHkvARE", "7jvQEcRanKo", "wuxIZ7I7qac", "wvdtuHDLy3g", "sDlU0s5Wex4", "CEtWgb7LmwE", "VCT9_7gr2L0", "Pkhe6465Deg", "GyC1nhgoWvY", "pdkO-EzCZdY", "hsNS49UwJkM", "zVjOjcYZQ98", "EZe3DTUqC4s", "gGehNOkhQk0", "THnwmyP1E64", "XMixclYowgQ", "6EzJsIrqq4M", "Lk0LW0AT5PM", "eaG2O8mhSf0", "BWsUSJgcl2w", "DEWtnXbLMrA", "qSFV9kgsfXk", "fUpn0EQEigQ", "LeuQ9usgLSA", "1fuwpjqRCgI", "m9dbWEwg_Mg", "p54cQEH9fKk", "1CtcZaSGCw8", "tXrpJnNi3tw", "qOagiIWLWq4", "T7MU0t3vl6c", "i7Xunb1kWgk", "ENe2UfDLEng", "n55eamWFpA4", "pqeyqGNcxqw", "SGoW1Tw49Qk", "XvVzH8zpPlQ", "Fvm_J5EGr6w", "ubSnezAhSSQ", "_DrQZdyYtiU", "6TY8ISknEYQ", "ysU_ZKI0Pqs", "Idva6aA34Gc", "-co-ULTn42U", "4vBZvvryzlk", "kDCv2SGfDHA", "PECu00EeiUw", "dek1SvfIK1w", "EgmsoL95nGU", "F5Xg7flOox8", "36Qw8y3vptg", "8XQdGxT4YCA", "B6WiT29xUkI", "dSbDMAhWlB0", "hHXt8LookLM", "EcZpQS4fqo0", "yn4fYZp5d-g", "7_tj_10u-bY", "mtTOKo62KiE", "TvuSDaO4qqc", "IJzosyUJNkc", "GTBJAE5cvjk", "LYRj5tb598E", "OvivJ4bem7k", "JtFN8G0NN4M", "4mKgUVU1htg", "72X15-tjgtI", "meht2cF355E", "nm76b8tzzWI", "tPbIlTf6szM", "K_B1x8E_mJc", "NgPuelwHVWI", "ugtj-3SbjnQ", "YJtkTpihOpA", "zmu1UMpvM9U", "Wc8wrIl87Yk", "BptlUB8zQBM", "oiqBzR-fov4", "ndfLhxou3SE", "sBW_uNH5JGY", "LeF7p8FkPbk", "mX1Lnl5ihXY", "poqvmQY7kbo", "uNgIjpvob8g", "FezieNodGDk", "pAxtT5abuf4", "2uZ5C39a-_o", "VU2d_Pld3w8", "sqZ-3zvs-38", "uhrW-fEmV70", "D0WpH_lCpkI", "97RYmWCcJVo", "o-0EUTFuK_g", "f3j0FPY3NO8", "hC3S0gid3eQ", "qLdcM-k1CnU", "M4Cty3xtXnM", "XStPdfNWCsA", "dkql3GrAqUQ", "aNvCzYItk7o", "joVmmYyorqk", "JdI1cnLiicc", "pZj7kDw5px4", "wOGBQMJg1Zc", "yxYubZ9oiXI", "2RDojFCBiUE", "HXGOrfa3kWU", "Jw6m2iJnH5s", "xwvWBpsKomY", "fwTyWLQ1DAY", "HKikSMn8OGY", "uiW7pR8vkzk", "26ThCj5ROoQ", "vUQQr8hqmrg", "8SHAu3MtLTY", "t6V-QPrnUvs", "RZB1T6qM4T0", "9QFyYG3FWHc", "Wj9aSPIAXmg", "R4WgXhuuoZU", "tth5vv0YLRo", "2R6w7i957TE", "faU9Yntu9dQ", "dp6EG4lfocA", "jcL-KJ7fdHA", "jbuRbmGobp8", "HA8WR7ybiuk", "oKtAZdqI118", "ybnai-l2TRQ", "eflckEy7n2k", "doQ-2xQT2E8", "Qbct1d2YntQ", "WzfInQ3h0T0", "5Qhfjp1rlG4", "f2v4tACU7Yk", "l3saFoaBBlc", "_fF6tqff1os", "kgxCNbQbJ9E", "K7ADD7ntlGQ", "unVKfbny1cY", "riFt0nHOirA", "-TTgqzO7Lb8", "qy7uDqD-zTE", "92vvxHe8_jI", "2oxzL0Om4f8", "sRmAMfyv4Dk", "4hQ_0W5GK6I", "YWcGhDdpUXc", "wwF6muodYfY", "gtNE5DnpD7c", "IlKyObPdtkc", "vkVNQMfHvA0", "ggXfgJkMj2o", "I_95xua5VmE", "ZmXBkAeJiJU", "Wn9DbLqD59s", "WqnbHnhDBj4", "WCmbXFc1RNs", "htYvN2rwQSo", "sXicOJKLkMA", "JbKaJK57-jc", "EHiPkU3jkkU", "2lbRdyBQAug", "kXdgykSLj-0", "GE2WCo1EmEU", "JHZV8SdjT7Q", "EenmmDx-RNo", "QEfFuNwcjZA", "0zldvi6V0ms", "TGi42Csclwc", "-XN_YI32fUE", "NQBfSZw1iy8", "r3oa1b9GIfg", "TpxfIwoYeV0", "lBYy31XAXd0", "2ecENqUh9XI", "L3KFb9pZU-k", "tOt1i464ieA", "9BWSmRZe3cg", "gAfvoaE8JSg", "vMrqS6zrTgA", "Zk_fg4Jg0H0", "V_065BbqL7A", "mnAu2B08Hhc", "6wEtakIyFkc", "bKaUU6Fja9M", "AVVpQ-cPx8Q", "fzom622AaZU", "rog2aEY7474", "M_kgHU9qeU8", "SAW-8eiS7I4", "JJa6Y_9Yg1o", "gRwixLpq_zo", "M8hR9O_GjKc", "399k1VAH1Hs", "05rRVo9gyR4", "0X7mZWLoxts", "Kak57iopz8A", "SxmhUwEu0iQ", "0rOztgGyFw4", "OWz7HLo39Ug", "O_v3SkwI8rY", "G5GcWFuExOk", "ykXjAc0DBXE", "VNDqN1IKDQ8", "kF5denZbFAU", "T0WAx3ZD8XQ", "xyxa7_wPgYk", "BSOtRifVdEM", "l_j89lUsB5g", "r1V085CXnF8", "RJCShPVydas", "pMlQ0bSLbhY", "YWH3ZWHygYQ", "hmIAK9o_zWE", "ilqgmjXusEc", "lqduJH-n5yw", "askyQJFAbbo", "J7n-VGbs5Pg", "fHg_guaU7dE", "_qg28d_Wd5E", "N9ELw3qDJ0o", "SSRBKK185eY", "qbGOVVkE-_I", "YXJuv0LkOKk", "ueXkki18eWw", "DPBPr9743YA", "AHUFrxr6Tv4", "7sjQhTEKwss", "_unmJAwUqPI", "1csuc5gk9KY", "buRrdnZTMVA", "QzDnwZHDPB0", "xQpsIklEvAk", "wB7gNp3jLvI", "wBCQApL7pMI", "BUZp8SdEuRg", "XtIvrXqnC-o", "KDNI0EhsU_A", "C-HpZPTLza8", "x-S58v9AgpQ", "AX51-e5mREM", "zoG_ZVcZ1hQ", "UKzt8YU24OU", "QFgFQ4KZgO4", "Xah5j9Ux16k", "N94NdgNzGe8", "TkKVR9Z0Sag", "IWoSM7Z2sv0", "AXcQMVT6IyM", "2dH31kmmWc4", "wE1yQ4vMrzY", "4hQ_0W5GK6I", "oSEg5vFEPTA", "ajfyTTV544I", "juXjwJJfE5g", "_uXjB279Nwk", "NhRyvWdqNWg", "bOBDc6Ha8SY", "oG_yGE3RLXI", "H5x20JFsAAU", "tsuTuCPK80Y", "Ynm6mZ0H7ZQ", "eHl07yWLbVQ", "UIg8qZ5FeXw", "5LXw9OJZqhY", "NT2X7KHAQE4", "WhZJ2WR-bMQ", "tD6L36I4vCM", "P9s5Fty3OZM", "5NBgVWq_DZw", "q6dY-hmCjsE", "KwDSfEXLaQ8", "Eb2EnORRBbg", "rCinpTzp-4M", "VF-VddNC944", "NVUD_X9ScSs", "zsDWuUuQ1oI", "xEBWYwnNcI0", "wSaOcVuQ00g", "WxRDIVu5Qf8", "krFBwpv3TDM", "c4_HI3_t4Ps", "xcr-Y7SAiRw", "ZQC1Kd5bGqo", "1l4Dm9k512k", "Q8fdMeiv3Zs", "ggjg_wmeBBs", "CeCa2ZansDQ", "XGr6xyZ2TEk", "cLJVKdfVvmw", "3Jp0cf-l0UA", "zNVd1cEyRI0", "U6kTTmXfeFw", "k3CA3-Rrjyk", "hwWiMfvTpDk", "8Jwiyi3OTgg", "fEq2SfLcKdM", "gDV-L_cML3g", "lI20gDmb7fU", "w4Z7BdGPqDY", "0Mpo-QXf5PM", "jxHtX9BOmyw", "7amRFESCyuE", "hqnCq7e4pz8", "hKv_Sk75PUw", "h-HQdSABBR8", "sAb9hYUwzvc", "zSBPTYJigQg", "jXvs7_vQxEE", "bD0u_ImEyCI", "swKIHnuM_MQ", "HvIgp1ERAFI", "qEzZJGpV24I", "3UEWv1qj_kQ", "3L-AoPCpLVE", "YcPAn8YXrxo", "37TAIPU2r3w", "NDxfnyJNjIg", "czzhAFt-Nu8", "v4aPVYtPr6w", "N48f8gfFgyk", "RAV3T53MnwE", "hmEr5n3mSfk", "H0rlpf5Y82U", "WFQ7WMupjuE", "mfofN2U_N_4", "_0KcAmFH7YU", "2JfwecMQVJ0", "KUtUxY1rXEo", "W4ZOCn1sBDk", "GQHIbAqWbz0", "lPVSbftbnL0", "x2wumFfteuM", "DLgJrh8rPv4", "Vg0jh-4pZ0A", "cPaquXtG9AA", "jrnHtmnqf2k", "clSFRi5uDhg", "l0pRW5R-MZg", "erE7eykP9Ss", "tO8av3rWqIE", "fN8hQNwDK_M", "ggT1Vsx0-X8", "s41xWafmU78", "0ou3PsWsLkQ", "Pgbvfok3usM", "yFL3Ms20QK0", "2u-IoVIMsmQ", "ffNe4QxQb94", "sd0nZKfEY54", "1IFn6WRveZA", "u1-HvQcBeJM", "SISwhkxcIXk", "HgE82AwQweg", "tyO1pPG-9Xk", "R3z_C3jIR9I", "rnqMOkMGo0o", "sUU1znVToGI", "PjKElDYPyvI", "DtPaViJap40", "lXw-lSBusxE", "BWLG-XCTnYQ", "van75zUvhgM", "U8Sl3opdNXY", "tu_HsXr04fs", "YfNHrTiniWg", "bdIVe47UJRc", "2-w4Dh_oBis", "TviqxNZFRzk", "8QYqWQqEAdA", "nUzmmP4U9Lw", "P1gfaU60tR8", "Ym5GjQMIpko", "7aVBjwCDwtc", "zLvK5va3RS4", "83IcC1HQ4eA", "2z4rsB56Mr8", "8XBlBPtQW6g", "bnG_UXtRRYg", "PSTAmAQ381s", "7mePxWHg_Kw", "CVFCoZgBytU", "shimnfvwdDo", "YlZZuod-Ros", "VQUbHoX1q28", "wIhm406dzU4", "FLT3QS5DIfU", "L_-LV0Nfj3I", "oROxNKHxGXI", "WDq0FWLbklc", "CUCVNU1Hudo", "D9PxiV83VG8", "ZR5zTPolS_w", "WRzxk3-pkfg", "jfkqS_cyMgo", "m8_ArzhhmHg", "3ClTxoNusns", "hNCEFlafLLI", "6GeZkWkfOYY", "px2Hv24OGEQ", "Vj3qnFKRThA", "OvB-xPgn3Ak", "w3fVYEcqNAE", "ZYgve5nEXpE", "fOP9QqvJmvs", "9BiC3j1XN10", "AAB-aeEHAvg", "9ZXDs5nmtMo", "nEsYkCmX1EU", "u-_tQ702wRo", "uDVhy6t-vmQ", "ZvKyq9wfzhI", "ICllBb4Sg9A", "qQELfknZXfg", "wO3RqSjRu4w", "Fd7GkrsmmIk", "7gdXuafuguU", "4LlNqD7q0uk", "yKROLtsd68c", "nbiDluN2fUI", "btq-83N7IYw", "Ji1DIFG1NLM", "mvhYig1qkaY", "moNCml_KeCA", "nXgXNyGR_Mg", "5LZtJ73qtrA", "h0yJY4UdVAw", "A-nJMNFWhQs", "39c1ADmxw00", "R-yNNEjLhIg", "7Vm2sT1RYEU", "LM1gJy95AW4", "HBZvSlp89e4", "VDzGuSAFd4Y", "romdGMcyYTE", "4sMwtvPMxm4", "uN-Ktd18L2Q", "PXhm8_jgllU", "QmH5o1GwLbs", "QTWo3Moc9aY", "QjegxxvqTSg", "a5hLzIrnF34", "OnmJgNwd23o", "1O1A_fWYje8", "I9lzouSyltE", "U_aIPlQbZzw", "X_QYVCsyFz0", "MsolmlyaL5Q", "Tl1EOU_TFhs", "frI3ljT7HR4", "puaLZmFyHoQ", "DNagSmrcUHI", "GFtyTiD8cS4", "WiTF3qDXu60", "xAaZkWNuMg4", "SyAJSnuipwg", "gEpLwLjVJKQ", "ugEzHDN-l8I", "Rgj2RsawbIc", "cWq0Z6rwp7c", "o-dm1HAI8vc", "68L5B1Ocjp4", "bcpXhQ6HX-4", "-fjHlDHttj8", "4Avery4h2h0", "CIAaMTBU70U", "_eUsIYRbAsM", "rnfD6V3ZxyA", "xtQ538mb42c", "gYmR4js2wEQ", "ha-Q5mIe7JY", "dka8wIQI_IA", "buRrdnZTMVA", "sACLkIooFss", "khcCnj6Qd8Q", "EDj0HyyG61g", "eDn8K9sj6eU", "UrcNLJN8IEU", "qf04ruypiW0", "wbAEiZyZs0g", "uKqRI2Eo1zs", "4rPZGSuAjFg", "HjtigsQXcNk", "L_AN7bqDzXc", "mNiXjSeHHVo", "OLqjSSVxBAk", "sWx-iaYKDBU", "TkXzOlytPME", "scsP_mzkbAk", "RQ3MDvOkXqY", "66Kr9pvC8Oo", "Uo2oh-tyDaM", "eD7JYqty8aE", "kzXSZTk-J8A"],
    // Geemu
    
    // Drama
    ["e-mdN0-1m5A", "Kak57iopz8A", "bSL1rTRl3X0", "aw7RZnDBga8", "pdGYNTrPAq8", "P62oy05RpXc", "e91WcG6kzdE", "4qWiEd3R_YY", "VlUA1bUYz-s", "IUG2IcgnLls", "fGkVxkJzhNU", "oX1SS8Sb9tI", "g0jsbfBWG7Q", "x59TJUh1F3g", "wytFXoa68CA", "KSgxypnZAdM", "eU6fDXnZp48", "6izZE0WQqUo", "EsgaaeVp-wQ", "23aqmAZk0jU", "uFfid73yREw", "IoNL187N38w", "wNThLk1SbaE", "CYQv75YRRI0", "WFc9O5zT6RU", "h0EMR-HaZSw", "WPpGPKlJpOw", "cdsJssonmzk", "OhG7Vy6t5lE", "WwCa7atJXu8", "eFGld2TVnFc", "LVK_2Tncw7k", "-GOWEYiGgQs", "kBOfdjnd5nw", "vxpoOctA9uY", "zL_jhV9O3Rk", "zs-WkPzSGpc", "gLJF3LK4mtI", "D-JGdqmt3cg", "9pby63jxOR0", "QDyD_sPk6HI", "tlzUYb42yD4", "OLPnwN76mZk", "dE8kurhf-vU", "HA2zr8huzJY", "iOaUaBaNttM", "XhpFRm7Pf4w", "5ODQ04sjM2A", "1IULf5QZjEE", "9FHwNNQDuMA", "_LLT5qH34IQ", "2yQ2gvSdUQU", "Pb1VUfgWtNY", "JNARFYM9e9E", "3eF1ZfVCq-Q", "4v8Mg6sv6FU", "uY_-TTXhEmQ", "ZQlv04J274Q", "fUf5pXm6JJs", "81FaXV1-BHw"],
    // Drama
    
    // Dansu
    ["-QhkTpmlfvM", "RORMpJVD3FE", "vHCLwx4tsP0", "l3mtxVXE4h8", "vEAgSCGmbb8", "dqjtKBMRNec", "AV0UJalH2y8", "D_cJ9JFGUYM", "-D3orpQPYts", "OoWCCNf7K9I", "EZ-ovY4eP5k", "vwBtv7P4apA", "tELmpYcrxp4", "Un4wdkxqP_U", "DqSA5VgV1ew", "XTtoUBxlX6g", "-C0ylyjfaoc", "ctLHZddI9CA", "F7xvpWhoUJw", "-EK1c4fAHKc", "EEyzUumwyXY", "_mkiGMtbrPM", "yzC4hFK5P3g", "RvujHeQZ_8s", "jmVDrxOPfO0", "Y6PFnsV7pdI", "qPFx7xcCBdY", "NS21Q48jEGA", "cFOr0VRlM6o", "a4BBNciJ_no", "OKJ4BPJVAEM", "JZ5DnIdhYAo", "Pv-_SV0qvVk", "r3kM4p0MMOA", "oqN50Ebdyuk", "MFu66ye6YWM", "KyxZ4Bpemvs", "RCX80NUZa34", "9NhDX9Z2JlA", "tT_adKXzQtU", "Z1YlySTug8w", "x24cRvLIb-g", "1rwk6Gl1UOM", "-7TWMq3agnc", "mZ_gd3porEU", "oVtHe73fNHg", "sy_dQsE1XNc", "d4jyDMqpW7Y", "1yVnkxJE_mg", "DfOVaJC5DfQ", "RKhOk-Ym-yg", "EYFfkHPBvMU", "qHi3busNoBM", "2ozu_5UIky4", "prfepwJ5wZE", "3mlIGU6j288", "eQe8Xpb7Yjw", "rP0w-aov9HA", "4-Raa3guXBU", "LbUdemNxkfE", "JfXR3RIjtwc", "w_os8HqfxHc", "Nvu9itUS8eU", "qYkicwSeXw0", "zXUTu8Lh5pw", "ENQITVSXJWs", "cVSvKmvUhNQ", "Et3BUOGsdT0", "38mhnLNIw2w", "Im7_ndxkLUg", "RTG7Azv8724", "rnbTIGx2DtU", "Ni7OqWPUPXg", "GFgpEXc65pI", "RoW0bmsSOmo", "Njp3f3aH1Y4", "3Pv6ZJ51vUk"],
    // Dansu
    
    // Tokusatsu
    ["Te3gUP1YgVQ", "mhd9dsQWqGw", "Joap7EmAtRA", "3HW1LneIitk", "av3OjrugBHM", "mrCCud065Rw", "LQ5QHwycKTU", "WTKVIGi3cVA", "u9CRTI_rD8M", "bbfR1A2daVA", "ncz-HRAcSI0", "5I4I9b5UhmQ", "bWiTUmaS5f4", "zsM8dpRMjQ0", "I1y9Dq3FSWw", "DK7iKDQBqp0", "5wA6UGTG0Bk", "1b-oN6_sGSo", "ZqCouhGjBHk", "_VOIKKDqZOM", "XfZTeJHxsJs", "9UWDgsWW3po", "nK3p5o7PT34", "ne8HWQhyVE4", "TEivI3yWuWQ", "-Q_8jnsfa7g", "FBksLrwBuAU", "_t8vTWbkcAU", "HUUcOOBh9M4", "BGof9bzwJHo", "cy1YGu87DS8", "VBhxJVM8Mdo", "QP7Yxwt4s54", "Di4oobMGQcE", "Zpe3PmFusNY", "EVIzaMm6yw8", "kOCV-Ka_ID4", "-4jXNunuQjA", "pqpBTsrGZ_Y", "q-C7jypcsGU", "myHpk4vOec4", "LQiFziyYpzI", "aV8IPQBaFqI", "Puo4uK7oHB4", "-JQOdj1LVw0", "R7YVi17OHc4", "9x3xcXhQ3GE", "WM1EdmPYew8", "MfQ2h8g4KOA", "EzbYh9h9olc", "DpMrVoiag1A", "plOS0gcy9dA", "HHMMfmnqz_8", "jU3q-hdoOnQ", "7j9m2InoPPo", "nE0PWflSBtA", "Z5aH-CpHL0s", "x29gUSwB24g", "zkXYT1T8Nv0", "eZewr-aZ5Pc", "Y22JHIJ5V_E", "7R1pA-SaFz0", "LGwOdPLZ9S8", "FAMbQ_gM7wU", "1WOaRBfQyR8", "Y2WuqGOPZmE", "M05y0xtv9T8", "wvx5ykgEUOU", "MZcWHoRM17M", "UnyuQLbJ_q8", "LjdduWuQ3M8", "PAdXJqf4kcM", "bGYQIeI3dVc", "A4Tlq2hlX84", "8wyHjvsHFf0", "hnqFBewOEds", "i-cEXCic7Fk", "acZohTM23Qw", "jrHK8NvhNzo", "4viCpjv2cbI", "BNcNb0hI-C4", "6Pq4Ysrh1Q8", "erxW7OPOX0I", "5a4kDEzikx4", "VLBCMNRkgmI", "AO18bmNDBfo", "JIobIlbLexI", "C6gfwkWltlA", "6cWtqx6K95Q", "srC91s5lc_8", "HMxj21YxaV4", "ROS30YgfkmI", "W69jbC2TgYw", "gfWWoSrDulg", "eYsCCTrY5AM", "M3XAbeinit8", "p0l6u3xGIds", "DfQYWPYhTNU", "bmZLiDk4i3c", "_pyEmTvx9jc", "oSsY99HN6Rs", "mwm6fw7lu3w", "q-mZJ3TXoE8", "11_bHxpv134", "uLPgl33ANCg", "DsLLg70A9Q0", "ZXChgeknCJ0", "NmX4uSDRaMY", "7-M73h3lNr8", "Ko4HfzURLRM", "mHjqj2mon7M", "QW9I_JBmBp8", "T8saNw1fo68", "VOIAQckxYlQ", "656QUkCYK8Q", "zzcXNQG3iSI", "ZgAMzanyzOg", "PcjLSHXPaLc", "HB0EHEwCszQ", "o22XVQq90D0", "AVRcpkAwvNo", "oYNh59bIEM4", "hyeUPTxQ3Gs", "kmG7w-9Xz3o", "YeZ0FgXCXIk", "Ya0Y4qS4iS0", "ec5Fg4gOUhk", "5Sx4U5Cs3wo", "3bwSOyUD7fI", "YYWHTpPC_gI", "xnchHxa4u_Q", "veeqGvovq68", "891B_Ahs8Yw", "pGry-9G49io", "l4he0Bd_0Wo", "kovJOPQNXuI", "cfkeFkY9zAs", "8VuGDPDv5a0", "PmXWGF0gPlY", "eEk8yxpjqgk", "OJaKP3ebjEU", "_17TbbX2xkY", "lvICxcLmgSs", "FBn-VEoOyps", "fXQ8hiVebsw", "jG8shc73XOQ", "aKvKMy5RDyI", "ctsV2YMyDSA", "pEhK6sTS_DA", "itlnRJzLc7g", "1Oc74oFkCVk", "iS9h7ZXfpss", "_RRaOG6CJeY", "5FYjYp8-QrE", "D9z9ajCPBhk", "XcEwHBFX2dU", "kCvYbu3KzSQ", "6Swcg7qkP5c", "7HgGsqF0Ghw", "B-Zivpxqc-4", "wWbUNaxE6TI", "iLEakrQqMgA", "fHFTfk1XfvE", "CNRgUI-Omts", "9MVWflfHAaA", "ZRoFVsuaJW8", "oIUNq9WIMK4", "CmW87AgL-T4", "YiEz8wQUqlU", "KN490VRNxUo", "09Yrdu10Ty4", "n_pThuLLGcE"],
    // Tokusatsu
    
    // Gravure
    ["ioe9L_cWJcg", "fAL-70KMKig", "69rPM2Jqn6o", "hkWdK6IIqzA", "UmjqsXtWJMg", "ut0ZBUkSvdg", "U2rdmT4ZQ7Y", "UDVl40o-INg", "qPvpFmnc5jA", "G1FdXP4WZ7I", "bKPTa37BXrQ", "kwpLNJAaX_M", "wJokZjLkEkk", "8Wa4k0iXbsM", "uYvPO71d5OM", "sPjh-GrTFmY", "xzXIA1AGGPA", "7_rYcip-FUA", "JbE36h5jClQ", "C7lgBk_gtdk", "MtfeDtA0I5I", "ROLqX-Hn_AQ", "6rygNpBsr58", "ueWSmkmeFX0", "84Hlfq5MkJY", "GCVCV0VWLpE", "b23kIhATN-A", "tctF3IYFdPI", "I6ht62AbeIE", "tuhpnHgRw7I", "FWn1VbO-tYE", "xSrzKwpDmqE", "1VrNCRxUZ1o", "x6t21YdJ2D0", "Y9eODhMdKmw", "8qjZUHC97js", "-XwnnPBvdWY", "DWYVvJLhTRE", "HO4eLTlhChM", "Ht8KwNDIVpk", "uxAfWYGhvtw", "WpoXGsHoDAU", "i43QZ6QWcp8", "rffGXZ4eop0", "j2JG8KIyxpU", "Q4pe7Q-FBz8", "OF5MoaQLuBA", "jDebJgq-Fpk", "sQHhzN78pdo", "5IDY3oxJrWQ", "GybZMNtHe_w", "QNzfLmz2b2s", "5JPPpWtxYc4", "I5ccNg52NV8", "d6T9dl3e-sA", "VMv3L47AxMA", "TGl00YmApn8", "8n2Rg1YLOH0", "QZmBya7cLFo", "lgVqy7JJmEs", "Z8CWbEnG5D0", "IS4vRFTvt3o", "5C-4YQFazl4", "dEIUXFhBihA", "pnRKUbbZXIE", "0FCLXQbRGfg", "qCe8knQZa0g", "dUItQLOTbTA", "VWKgNPK9MGU", "DI8c99-4ex0", "OPI-AUI871s", "4CgketoLb4s", "E-PVf7GDprg", "IGkA_YcaDas", "AgiAEwvkxtI", "8qaRWGf8mMc", "fRPICw-zDiM", "ZTeFdIiI6yI", "l-XpZOTbelc", "QpZrnOD-7IM", "ocOrSeuWbbM", "ZAznzafgces", "F0fE6pXoIZQ", "PZ41M5q3byA", "TWVq4SHLoCU", "INkyRsnkjHY", "URaZjj949xU", "EVbuIT2vAJg", "dXb8QC92rrI", "Md1dUdq0NfM", "yPY6flhrfr0", "1bvNYPr5Jr8", "ndHuNQFk8wg", "30PGUqPTgiI", "n7pgTbKpVKU", "oVosyUrpKD8", "uXqrVmhh7IE", "VSSTnGg4BW8", "rWNQn19RefY", "OfWiWJMwQ1Q", "TUT5As80dUo", "H5LDzUHgY3c", "9wGC6HWz_CA"],
    // Gravure
    
    // Aspect ratio fix
    ["U79eYdqEwQI", "XStPdfNWCsA", "sVRMSmftZZM", "CW8h_1eNnEg", "V45XFQfncWA", "Tn7rx0SnPuk", "erIxiBsR-wg", "8NtsRrT-sBU", "-QhkTpmlfvM", "PvcE9D3mn0Q", "sxRJY-xTRo0", "zeKxDEKsigQ", "mtTOKo62KiE", "EcZpQS4fqo0", "fGkVxkJzhNU", "i43QZ6QWcp8", "WpoXGsHoDAU", "VSSTnGg4BW8", "rffGXZ4eop0", "j2JG8KIyxpU", "bKPTa37BXrQ", "VWKgNPK9MGU", "fAL-70KMKig", "QpZrnOD-7IM", "pZj7kDw5px4", "1sq1N1sBGsA", "6PVWBuZqBkM", "6vRa61ST0Qg", "xwvWBpsKomY", "uiW7pR8vkzk", "qQFuxY4CjZc", "hanHrpg-n_Y", "ybnai-l2TRQ", "mhd9dsQWqGw", "eflckEy7n2k", "l3saFoaBBlc", "9Ou7z9Yv3yg", "I_95xua5VmE", "VRQByyTT__I", "ZmXBkAeJiJU", "eU6fDXnZp48", "fCwOqidHkPQ", "V_065BbqL7A", "_k3Jq_h70HE", "EWh8z_22SP8", "l_j89lUsB5g", "r1V085CXnF8", "YWH3ZWHygYQ", "YXJuv0LkOKk", "ueXkki18eWw", "mTmoGlWKj7A", "N94NdgNzGe8", "Eb2EnORRBbg", "qEzZJGpV24I", "3UEWv1qj_kQ", "YcPAn8YXrxo", "AHOJo6ne9zg", "l1S2HApi37g", "Lq1uoAa2WQg", "hmEr5n3mSfk", "H0rlpf5Y82U", "jrnHtmnqf2k", "erE7eykP9Ss", "sd0nZKfEY54", "1IFn6WRveZA", "5wA6UGTG0Bk", "eQe8Xpb7Yjw", "fLPfFAMlJzI", "DtPaViJap40", "RK4dm6q4D3g", "dQw4w9WgXcQ", "AiZu3AXVm-U", "8aAV0b35odw", "n5ahcFz4iF8", "Cwq-HPJ1Nfo", "TviqxNZFRzk", "8QYqWQqEAdA", "nUzmmP4U9Lw", "7aVBjwCDwtc", "zLvK5va3RS4", "2z4rsB56Mr8", "CVFCoZgBytU", "shimnfvwdDo", "YlZZuod-Ros", "tLWSwvvPnmQ", "uDSVcBb6CnU", "GxtVw7_JEqE", "9vAi6gF2ZfU", "YeM19uf75MU", "oVhCCEWgT9U", "P1gfaU60tR8", "7LGQ9NSDZbU", "pAxtT5abuf4", "u-_tQ702wRo", "LVK_2Tncw7k", "kBOfdjnd5nw", "-GOWEYiGgQs", "vxpoOctA9uY", "zL_jhV9O3Rk", "zs-WkPzSGpc", "IovywlBHXZI", "euYu86eRDdg", "XauesGq81pc", "xAAfTWtm4w0", "AkuGYYo4cik", "y6UN1n75D7E", "8btq5vdFAVY", "DkoRf5gPQxQ", "X6kfhmMOM8o", "ZcvitejWOms", "gLJF3LK4mtI", "oJRAW0r0giE", "D-JGdqmt3cg", "Ni7OqWPUPXg", "HA2zr8huzJY", "8kbB4fEXymM", "DcgfJvpAdjg", "XhpFRm7Pf4w", "t3_QWak7tCY", "ZnYvTkaf9EU", "Pb1VUfgWtNY", "TkXzOlytPME", "scsP_mzkbAk", "RQ3MDvOkXqY", "0eX9v1ikRJA", "5sSI3gjZ7KA", "SYyoKrZS5Do", "M8Q2YFFk69c", "yw2i8iVFMZ0", "WLuzycBBNBs", "3oY3dF75gAU", "DXhOVxsZc-k", "oyz_pPvJ7Bw", "ADEecDBDpc0", "piMqsaaHz4Q", "YsXXhkIgLUg", "tjKkxjhjjOg", "zQ86-oQ8jrY", "bR1ybgB3IR0", "nVHeTt7HPmg", "m77YkIqaEHE", "YtqHzLXZqQE", "boU8FXGKoAw", "kcjYOB7-Tjw", "RRTwxfl-Z9o", "sKswNdKOhfw", "p97OBKxsGn8", "TwCbuMkjGYI", "Pp5Gm2JC3HM", "kM9OTG8eccM", "rPQIbd50-9w", "8Ig8BxjyUJI", "pVTPIX1aD7k", "gIQQB5kTWRs", "OoJin9fmsPY", "qZdJI6jMbpY", "BQf5j0vxUYA", "ieLChSKnMKo", "LKlrjfOgE5E", "LkPYMHm-VSU", "gO9lE9YT59w", "pAHHpYdADAQ", "TEivI3yWuWQ", "otHhik1Ngng", "zJl7UbocCTg", "11_bHxpv134", "uLPgl33ANCg", "DsLLg70A9Q0", "ZXChgeknCJ0", "NmX4uSDRaMY", "7-M73h3lNr8", "Ko4HfzURLRM", "mHjqj2mon7M", "QW9I_JBmBp8", "T8saNw1fo68", "VOIAQckxYlQ", "656QUkCYK8Q", "zzcXNQG3iSI", "ZgAMzanyzOg", "PcjLSHXPaLc", "HB0EHEwCszQ", "o22XVQq90D0", "AVRcpkAwvNo", "oYNh59bIEM4", "hyeUPTxQ3Gs", "kmG7w-9Xz3o", "YeZ0FgXCXIk", "Ya0Y4qS4iS0", "ec5Fg4gOUhk", "5Sx4U5Cs3wo", "3bwSOyUD7fI", "YYWHTpPC_gI", "xnchHxa4u_Q", "veeqGvovq68", "891B_Ahs8Yw", "pGry-9G49io", "l4he0Bd_0Wo", "kovJOPQNXuI", "cfkeFkY9zAs", "8VuGDPDv5a0", "PmXWGF0gPlY", "eEk8yxpjqgk", "OJaKP3ebjEU", "jG8shc73XOQ", "dluWHvqCEjA", "W_6pgez53RQ", "LJMW9T97hfI", "N75DOjkr5og", "P4YIWwSBp4w", "M0Zc5REWaJc", "4UfhknxN_TQ", "aqJEjigA7Og", "b23kIhATN-A", "qu0X6QKkEyk"],
    // Aspect ratio fix
    
    // Debug
    // []
    ["8kaMTqfHdPM", "w9V3x61D994", "A07uMRUATTA", "GMA7co9BHjA", "oavMtUWDBTM", "dQw4w9WgXcQ", "AiZu3AXVm-U", "wWv9176ZnuU", "2tuUQVXsNj4", "enN8YxLnCb8", "3mTkB4-I9lk", "olm7xC-gBMY", "Cp-Ys_iFwnM", "bvLwipBosOs", "7urRkXEgWKk", "3k5KWFnnXK4", "FGfGhUl-iUs", "n5ahcFz4iF8", "xK6A6aoLaZA", "9Nl-vm4UTVM", "n7mtJ3ZV6xM", "128IR21ZQa0", "Ar4WzQ7KHak", "kYxlSDJZbn0", "2NNMHxqJp6A", "9dXKIfSFwt0", "kRc3RTHE75E", "7LGQ9NSDZbU", "q1iKiX-58Ao", "tLWSwvvPnmQ", "ppQ8npI6x28", "1nCqRmx3Dnw"]
    // Debug
  ];
  
  /* Video player setup */
  const TV_VIDEO = document.getElementById("tv-video");
  const TV_CHANBTN = Array.from(document.getElementsByClassName("tv-chanbtn"));
  
  // Loading
  TV_VIDEO.onwaiting = function() {
    tvStatic();
  };
  
  // Playing
  TV_VIDEO.onplaying = function() {
    if (CHANNELS[8].includes(cur_chan[cur_index])) {TV_VIDEO.style.objectFit = "cover";}
    else {TV_VIDEO.style.objectFit = "fill";}
    tvStatic(false);
    tvIdLink(true);
  };
  
  // End
  TV_VIDEO.onended = function() {
    if (navigator.onLine || is_offline_mode) {tvNext();}
    else {tvStatic();}
  };
  
  // Error
  TV_VIDEO.onerror = function() {
    const SRC_ERRORS = [MediaError.MEDIA_ERR_ABORTED, MediaError.MEDIA_ERR_NETWORK];
    
    // Source error
    if (!SRC_ERRORS.includes(this.error.code)) {
      // Retry idlink format
      const idlinks_check = [0, 4];
      if (!is_offline_mode && !idlinks_check.includes(idlinks_mode)) {
        switch (idlinks_mode) {
          case 1:
            TV_VIDEO.src = TV_VIDEO.src.replace("itag=43", "itag=18");
            idlinks_mode = 2;
            break;
          case 2:
            TV_VIDEO.src = TV_VIDEO.src.replace("itag=18", "itag=43") + "&local=true";
            idlinks_mode = 3;
            break;
          case 3:
            TV_VIDEO.src = TV_VIDEO.src.replace("itag=43", "itag=18");
            idlinks_mode = 4;
            break;
          default:
            break;
        }
      }
      // Next video & debug message
      else {
        tvDebug(1, true);
        tvNext();
      }
    }
    // Network error
    else if (this.error.code === MediaError.MEDIA_ERR_NETWORK) {
      // Show static and pause
      TV_VIDEO.pause();
      tvStatic();
      // Store current video time
      cur_index = [cur_index, TV_VIDEO.currentTime];
    }
  };
  
  // Return online after network error
  document.body.ononline = function() {
    // Restart video at last position
    if (typeof(cur_index) !== "number") {tvNext(cur_index[0]);}
    else {tvNext();}
  };
  
  // Save cookie for volume
  window.onunload = function() {
    try {document.cookie = "vol=" + TV_VIDEO.volume + "; expires=Fri, 31 Dec 9999 23:59:59 GMT";}
    catch (e) {return;}
  };
  
  // Mouseover screen channel name
  document.getElementById("tv-fs").onmouseover  = function() {
    tvChanName(undefined, 1500);
  };
  
  /* Hotkeys */
  const TV_DOC = document.getElementById("tv-doc");
  
  TV_DOC.addEventListener("keydown", function(e) {
    const HOTKEYS = ["ArrowUp", "ArrowDown", "ArrowRight", "ArrowLeft", "Enter", "PageDown", "PageUp", "1", "2", "3", "4", "5", "6", "7", "8", "F1", "D", "0", "+", "-", "Insert", "Delete", "Backspace"];
    if (HOTKEYS.includes(e.key)) {e.preventDefault();}
    switch (e.key) {
      // Channel adjust
      case HOTKEYS[0]:
        tvChanAdjust();
        break;
      case HOTKEYS[1]:
        tvChanAdjust(true);
        break;
      // Volume adjust
      case HOTKEYS[2]:
        tvVolAdjust();
        break;
      case HOTKEYS[3]:
        tvVolAdjust(true);
        break;
      // Fullscreen
      case HOTKEYS[4]:
        tvFullscreen();
        break;
      // Next
      case HOTKEYS[5]:
        tvNext();
        break;
      // Show channel name
      case HOTKEYS[6]:
        tvChanName(undefined, 1500);
        break;
      // Channel buttons
      case HOTKEYS[7]:
        TV_CHANBTN[0].click();
        break;
      case HOTKEYS[8]:
        TV_CHANBTN[1].click();
        break;
      case HOTKEYS[9]:
        TV_CHANBTN[2].click();
        break;
      case HOTKEYS[10]:
        TV_CHANBTN[3].click();
        break;
      case HOTKEYS[11]:
        TV_CHANBTN[4].click();
        break;
      case HOTKEYS[12]:
        TV_CHANBTN[5].click();
        break;
      case HOTKEYS[13]:
        TV_CHANBTN[6].click();
        break;
      case HOTKEYS[14]:
        TV_CHANBTN[7].click();
        break;
      // Show hotkey list
      case HOTKEYS[15]:
        let hotkey_text = "テレビソフト「1.0」\n- Hotkeys -\nArrowUp/Down: Channel up/down\nArrowLeft/Right: Volume minus/plus\nEnter: Toggle fullscreen mode\nPageDown: Next program\nPageUp: Show current channel name\n1-8: Switch to channel\nF1: Show hotkey list\nShift + D: Toggle debug mode";
        if (is_debug) {hotkey_text += "\n\n- Debug hotkeys -\n0: Switch to debug channel\n+: Show current video info\n-: Seek in video\nInsert: Aspect ratio mode cover\nDelete: Aspect ratio mode fill\nBackspace: Change video source";}
        alert(hotkey_text);
        break;
      // Toggle debug mode
      case HOTKEYS[16]:
        let debug_text = "Debug mode turned on\nSee hotkey list (F1) for debug functions";
        if (!is_debug) {is_debug = true;}
        else {is_debug = false; debug_text = debug_text.substr(0, 19) + "ff";}
        tvAlert(debug_text, true);
        break;
      // Debug channel
      case HOTKEYS[17]:
        tvDebug(0, CHANNELS[9]);
        break;
      // Debug current video info
      case HOTKEYS[18]:
        tvDebug(1);
        break;
      // Debug video seek
      case HOTKEYS[19]:
        tvDebug(2);
        break;
      // Debug aspect cover
      case HOTKEYS[20]:
        tvDebug(3);
        break;
      // Debug aspect fill
      case HOTKEYS[21]:
        tvDebug(4);
        break;
      // Debug new video source
      case HOTKEYS[22]:
        tvDebug(5);
        break;
      default:
        break;
    }
  });
  
  /* Button setup */
  let doubletap = null;
  
  // Vol up
  document.getElementById("tv-volup").onclick = function() {
    doubletap = false;
    tvVolAdjust();
    doubletap = null;
  };
  
  // Vol down
  document.getElementById("tv-voldn").onclick = function() {
    doubletap = false;
    tvVolAdjust(true);
    doubletap = null;
  };
  
  // Channel buttons
  TV_CHANBTN.forEach(function(elem) {
    elem.onclick = function() {
      doubletap = false;
      if (!navigator.onLine && !is_offline_mode) {return;}
      const index = TV_CHANBTN.indexOf(elem);
      if (cur_chan !== CHANNELS[index]) {cur_chan = CHANNELS[index]; cur_played = []; tvChanName("CH" + (index + 1));}
      tvNext();
      doubletap = null;
    };
  });
  
  // Fullscreen
  document.getElementById("tv-fs").onclick = function() {
    doubletap = false;
    tvFullscreen();
    doubletap = null;
  };
  
  /* Mobile gestures */
  let tap_x;
  let tap_y;
  let swipe_hor = null;
  
  // Tap screen
  TV_DOC.addEventListener("touchstart", function(e) {
    // Init swipe gestures
    tap_x = e.touches[0].clientX;
    tap_y = e.touches[0].clientY;
    
    // Tap & doubletap for show chan name & next
    if (doubletap === null) {
      doubletap = setTimeout(function () {
        tvChanName(undefined, 1500);
        doubletap = null;
      }, 500);
    }
    else if (!!doubletap) {
      clearTimeout(doubletap);
      tvNext();
      doubletap = null;
    }
  });
  
  // Swipe vol & channel
  TV_DOC.addEventListener("touchmove", function(e) {
    if (!tap_x || !tap_y) {return;}
    
    let diff_x = tap_x - e.touches[0].clientX;
    let diff_y = tap_y - e.touches[0].clientY;
    
    if (swipe_hor === null) {
      swipe_hor = Math.abs(diff_x) > Math.abs(diff_y) ? true : false;
    }
    
    if (swipe_hor) {
      // Left
      if (diff_x > 0) {tvVolAdjust(true);}
      // Right
      else {tvVolAdjust();}                       
    }
    else {
      // Up
      if (diff_y > 0) {tvChanAdjust();}
      // Down
      else {tvChanAdjust(true);}
    }
  });
  
  // Swipe end reset
  TV_DOC.ontouchend = function() {
    swipe_hor = null;
  };
  
  /* Misc settings & start */
  // Timers
  tvVolAdjust.ready = true;
  tvChanAdjust.ready = true;
  tvVolAdjust.vol_fade = undefined;
  tvChanName.chan_fade = undefined;
  
  // Random channel
  let start_index = 8;
  while (start_index > 7) {start_index = tvRandom(CHANNELS);}
  cur_chan = CHANNELS[start_index];
  tvChanName("CH" + (start_index + 1));
  
  // Volume
  try {
    if (document.cookie.match(/vol=[\d\.]+/) !== null) {tvVolSet(parseFloat(document.cookie.match(/vol=([\d\.]+)/)[1]));}
    else {tvVolSet(0.5);}
  }
  catch (e) {tvVolSet(0.5);}
  
  // Start
  tvNext();
}

document.body.onload = function() {tvInit();};